@@ -18,15 +18,6 @@
 #include "parser.h"
 #include "thrift/rpc_thrift_enum.h"
 
-#ifndef _WIN32
-#include <unistd.h>
-#include <sys/param.h>
-#else
-#define MAXPATHLEN 4096
-#include <direct.h>
-#endif
-
-
 #define LINE_LENGTH_MAX 2048
 
 static std::string gen_param_var(const std::string& type_name, size_t& cur,
@@ -48,25 +39,13 @@ void parse_thrift_type_name(const std::string& type_name,
 
 bool Parser::parse(const std::string& proto_file, idl_info& info)
 {
-	char current_dir[MAXPATHLEN] = {};
-	std::string dir_prefix;
+	std::string idl_file = info.input_dir + proto_file;
 
-	auto pos = proto_file.find_last_of('/');
+	auto pos = idl_file.find_last_of('/');
 	if (pos == std::string::npos)
-		info.file_name = proto_file;
+		info.file_name = idl_file;
 	else
-	{
-		info.file_name = proto_file.substr(pos + 1);
-
-		if (proto_file[0] == '/')
-			dir_prefix = proto_file.substr(0, pos + 1);
-		else
-		{
-			getcwd(current_dir, MAXPATHLEN);
-			dir_prefix = current_dir;
-			dir_prefix += "/";
-		}
-	}
+		info.file_name = idl_file.substr(pos + 1);
 
 	pos = info.file_name.find_last_of('.');
 	if (pos == std::string::npos)
@@ -74,17 +53,17 @@ bool Parser::parse(const std::string& proto_file, idl_info& info)
 	else
 		info.file_name_prefix = info.file_name.substr(0, pos + 1);
 
-	info.absolute_file_path = proto_file;
+	info.absolute_file_path = idl_file;
 
-	FILE *in = fopen(proto_file.c_str(), "r");
+	FILE *in = fopen(idl_file.c_str(), "r");
 	if (!in)
 	{
 		fprintf(stderr, "[Parser] proto file: [%s] not exists.\n",
-				proto_file.c_str());
+				idl_file.c_str());
 		return false;
 	}
 
-	fprintf(stdout, "proto file: [%s]\n", proto_file.c_str());
+	fprintf(stdout, "proto file: [%s]\n", idl_file.c_str());
 
 	char line_buffer[LINE_LENGTH_MAX];
 	std::string file_path;
@@ -138,7 +117,7 @@ bool Parser::parse(const std::string& proto_file, idl_info& info)
 			{
 				fprintf(stderr, "[Parser ERROR] %s must not set "
 						"\"option cc_generic_services = true\" for srpc.\n",
-						proto_file.c_str());
+						idl_file.c_str());
 				return false;
 			}
 		}
@@ -154,13 +133,16 @@ bool Parser::parse(const std::string& proto_file, idl_info& info)
 					continue;
 			}
 
-			file_path = dir_prefix + file_path;
-
 			info.include_list.resize(info.include_list.size() + 1);
+			info.include_list.back().input_dir = info.input_dir;
+
 			succ = this->parse(file_path, info.include_list.back());
 			if (!succ)
 			{
 				info.include_list.pop_back();
+				fprintf(stderr, "[Parser ERROR] failed to parse "
+						"\" %s \" in \" %s \"\n",
+						file_path.c_str(), idl_file.c_str());
 				return false;
 			}
 
@@ -170,7 +152,7 @@ bool Parser::parse(const std::string& proto_file, idl_info& info)
 		if (this->is_thrift &&
 			this->parse_thrift_typedef(line,
 									   old_type_name,
-									   new_type_name,info) == true)
+									   new_type_name, info) == true)
 		{
 			info.typedef_list.push_back(typedef_descriptor{old_type_name,
 														   new_type_name});
@@ -303,7 +285,7 @@ bool Parser::parse(const std::string& proto_file, idl_info& info)
 
 	build_typedef_mapping(info);
 	fclose(in);
-	fprintf(stdout, "finish parsing proto file: [%s]\n", proto_file.c_str());
+	fprintf(stdout, "finish parsing proto file: [%s]\n", idl_file.c_str());
 	return true;
 }
 
@@ -474,20 +456,6 @@ int Parser::parse_pb_rpc_option(const std::string& line)
 	return 2;
 }
 
-bool Parser::parse_dir_prefix(const std::string& file_name, char *dir_prefix)
-{
-	size_t pos = file_name.length() - 1;
-	while (file_name[pos] != '/' && pos != 0)
-		pos--;
-
-	if (pos == 0)
-		return false;
-
-	snprintf(dir_prefix, pos + 2, "%s", file_name.c_str());
-//	fprintf(stderr, "[%s]------------[%s]\n", file_name.c_str(), dir_prefix);
-	return true;
-}
-
 bool Parser::parse_thrift_typedef(const std::string& line,
 								  std::string& old_type_name,
 								  std::string& new_type_name,
